@@ -31,13 +31,13 @@ import BeautifulSoup
 
 # Global settings
 TIMEOUT=5
-CYCLETIME=1.5
+CYCLETIME=3
 CONFIG_DEFAULTS={'timeout':TIMEOUT,'cycletime':CYCLETIME,'userid':'admin','password':'4321','hostname':'192.168.0.100'}
 CONFIG_FILE=os.path.expanduser('~/.dlipower.conf')
 
 class powerswitch:
     """ Powerswitch class to manage the Digital Loggers Web power switch """
-    def __init__(self,userid=None,password=None,hostname=None,timeout=None):
+    def __init__(self,userid=None,password=None,hostname=None,timeout=None,cycletime=None):
         CONFIG=self.load_configuration()
         if userid:
             self.userid=userid
@@ -55,6 +55,10 @@ class powerswitch:
             self.timeout=float(timeout)
         else:
             self.timeout=CONFIG['timeout']
+        if cycle_time:
+            self.cycle_time=float(cycle_time)
+        else:
+            self.cycle_time=CONFIG['cycletime']
     def load_configuration(self):
         """ Return a configuration dictionary """
         if os.path.isfile(CONFIG_FILE):
@@ -181,12 +185,13 @@ if __name__ == "__main__":
     parser = optparse.OptionParser(usage=usage)
     parser.add_option('--hostname',dest='hostname',default=None,help="hostname/ip of the power switch (default %default)")
     parser.add_option('--timeout',dest='timeout',default=None,help="Timeout for value for power switch communication (default %default)")
+    parser.add_option('--cycletime',dest='cycletime',default=None,type=int,help="Delay betwween off/on states for power cycle operations (default %default)")
     parser.add_option('--user',    dest='user',    default=None        ,help="userid to connect with (default %default)"         )
     parser.add_option('--password',dest='password',default=None         ,help="password (default %default)"                       )
     parser.add_option('--save_settings',dest='save_settings',default=False,action='store_true',help='Save the settings to the configuration file')
     (options, args) = parser.parse_args()
 
-    switch=powerswitch(userid=options.user,password=options.password,hostname=options.hostname,timeout=options.timeout)
+    switch=powerswitch(userid=options.user,password=options.password,hostname=options.hostname,timeout=options.timeout,cycletime=options.cycletime)
     if options.save_settings:
         switch.save_configuration()
     if len(args):
